@@ -99,10 +99,16 @@ class User(AbstractBaseUser, PermissionsMixin):
         """
         send_mail(subject, message, from_email, [self.email], **kwargs)
 
+    def _get_base_sg_context(self):
+        return {
+            'first_name': self.first_name,
+            'last_name': self.last_name,
+            'email': self.email,
+        }
+
     def send_verification_email(self):
 
         token = generate_verify_email_token(self.id, self.email)
-        SG_TEMPLATE_ID = "d-f45aba387d824c15a5d6a9b4e97646b7"
 
         sg_context = {
             'first_name': self.first_name,
@@ -117,40 +123,10 @@ class User(AbstractBaseUser, PermissionsMixin):
             'info@rippleenergy.com',
             [self.email],
             html_message='_',
-            sg_template_id=SG_TEMPLATE_ID,
+            sg_template_id=settings.SG_TL_EMAIL_VERIFICATION,
             sg_context=sg_context
         )
 
-    def send_sign_up_email(self):
-
-        try:
-
-            token = generate_verify_email_token(self.id, self.email)
-
-            template_params = {
-                'user': self,
-                'url': '%s/account/verify?token=%s' % (settings.SITE_URL, token),
-            }
-
-            msg_plain = render_to_string(
-                'user_signup_email.txt', template_params)
-            msg_html = render_to_string(
-                'user_signup_email.html', template_params)
-
-            # TODO how does __rippleweb___ work?
-
-            filtered_send_mail(
-                'Welcome to ___rippleweb___',
-                msg_plain,
-                'support@example.com',
-                [self.email],
-                html_message=msg_html,
-                fail_silently=False,
-            )
-        except Exception as ex:
-            # TODO red log email send failure
-            pass
-
     def send_password_reset_email(self):
 
         uidb64 = urlsafe_base64_encode(force_bytes(self.pk)).decode()
@@ -159,8 +135,6 @@ class User(AbstractBaseUser, PermissionsMixin):
         url = f"{settings.SITE_URL}/account/reset-password-confirm"
         url += f"?uidb64={uidb64}&token={token}"
 
-        SG_TEMPLATE_ID = "d-d56fbf35e1f247ddb7f7f2c372bdea44"
-
         sg_context = {
             'first_name': self.first_name,
             'url': url
@@ -172,14 +146,44 @@ class User(AbstractBaseUser, PermissionsMixin):
             'support@rippleenergy.com',
             [self.email],
             html_message='_',
-            sg_template_id=SG_TEMPLATE_ID,
+            sg_template_id=settings.SG_TL_RESET_PASSWORD,
             sg_context=sg_context
         )
 
-    def send_password_reset_confirmed_email(self):
+    def send_password_changed_confirmed_email(self):
         # sends a confirmation to someone that their password has been changed
         # TODO red
-        pass
+        return
+        return filtered_send_mail(
+            '_',
+            '_',
+            'info@rippleenergy.com',
+            [self.email],
+            html_message='_',
+            sg_template_id=settings.SG_TL_PASSWORD_CHANGED_CONFIRMED,
+            sg_context=sg_context
+        )
+
+    def send_email_changed_email(self, old_email_address):
+        """
+        Sends email to a user's old email address 
+        to notify that their email has been changed.
+        """
+        return
+        sg_context = {
+            'old_email': old_email_address,
+            **self._get_base_sg_context()
+        }
+
+        return filtered_send_mail(
+            '_',
+            '_',
+            'info@rippleenergy.com',
+            [old_email_address],
+            html_message='_',
+            sg_template_id=settings.SG_TL_EMAIL_CHANGED_NOTIFY,
+            sg_context=sg_context
+        )
 
 
 class RippleBase(models.Model):
@@ -283,4 +287,3 @@ class FeatureUrl(RippleBase):
 
     def __str__(self):
         return "{} {}".format(self.feature.name, self.regex[:20])
-
