@@ -51,12 +51,14 @@ class UserSerializer(serializers.ModelSerializer):
     def update(self, instance, validated_data):
 
         email_changed = False
-        
-        if not self.partial and validated_data.get('email') is not None:
+        current_email_address = instance.email
+
+        if "email" in validated_data and validated_data.get('email') is not None:
 
             email_changed = instance.email != validated_data['email']
 
         if email_changed:
+
             instance.is_email_verified = False
 
         instance = super().update(instance, validated_data)
@@ -64,6 +66,7 @@ class UserSerializer(serializers.ModelSerializer):
         if email_changed:
             try:
                 instance.send_verification_email()
+                instance.send_email_changed_email(current_email_address)
             except:
                 # don't want email send exceptions to block updates
                 pass
@@ -233,12 +236,6 @@ class SignUpSerializer(serializers.ModelSerializer):
         user = user_model.objects.create_user(**validated_data)
         return user
 
-    def save(self, **kwargs):
-
-        super().save(**kwargs)
-
-        # self.instance.send_sign_up_email()
-
 
 class LoginSerializer(serializers.Serializer):
 
