@@ -32,7 +32,6 @@ class AuthenticationTestData:
     def setUpTestData(cls):
 
         cls.user = UserFactory()
-
         super().setUpTestData()
 
 
@@ -122,7 +121,7 @@ class AccountStatusViewTestCase(
         }
 
         response = self.client.get(self.end_point)
-        
+
         for key in expected.keys():
             self.assertEqual(response.data[key], expected[key])
 
@@ -163,7 +162,7 @@ class SignUpTests(AuthenticationTestData):
 
     def test_can_sign_up(self, *args):
         response = self.get_valid_post_response()
-        
+
         self.assertEqual(response.status_code, 201)
         self.assertEqual(
             self.get_user_response_data(response),
@@ -188,6 +187,36 @@ class SignUpTests(AuthenticationTestData):
         self.assertDictEqual(
             self.get_user_response_data(response),
             {'email': ['user with this email address already exists.']}
+
+        )
+
+    def test_cant_sign_up_with_bad_phone_number(self, *args):
+        response = self.get_valid_post_response(
+            {
+                'phone_number': 'bad',
+            }
+        )
+
+        self.assertEqual(response.status_code, 400)
+
+        # TODO red look in drf for "(model) with this (field)..." exists
+        self.assertDictEqual(
+            self.get_user_response_data(response),
+            {'phone_number': ['Phone number is not a valid UK number.']}
+        )
+
+        response = self.get_valid_post_response(
+            {
+                'phone_number': '012312',
+            }
+        )
+
+        self.assertEqual(response.status_code, 400)
+
+        # TODO red look in drf for "(model) with this (field)..." exists
+        self.assertDictEqual(
+            self.get_user_response_data(response),
+            {'phone_number': ['Phone number is not a valid UK number.']}
         )
 
     def test_cant_sign_up_with_bad_email(self, *args):
