@@ -390,7 +390,8 @@ class PasswordResetConfirmView(GenericAPIView):
         serializer.is_valid(raise_exception=True)
 
         serializer.save()
-        # TODO red - log in after reset?
+
+        serializer.user.send_password_changed_confirmed_email()
 
         login_(request, serializer.user)
         return Response({'detail': _('Password has been updated.')})
